==> billogram-foundation-4.6.4.tgz: package/modules/components/switch/Switch.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Switch from './Switch';


const TestSwitch = Switch({
    block: purebem.of('test-switch'),
    displayName: 'TestSwitch'
});

test('should be checked when clicked and is unchecked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).toHaveBeenCalledWith(true);
});

test('should be unchecked when clicked and is checked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).toHaveBeenCalledWith(false);
});

test('should remain unchecked when disabled and clicked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).not.toHaveBeenCalled();
});

test('should remain checked when disabled and clicked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).not.toHaveBeenCalled();
});

test('should be checked when using space and is unchecked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).toHaveBeenCalledWith(true);
});

test('should be unchecked when using space and is checked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).toHaveBeenCalledWith(false);
});

test('should remain unchecked when disabled and using space', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).not.toHaveBeenCalled();
});

test('should remain checked when disabled and using space', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).not.toHaveBeenCalled();
});

==> billogram-foundation-4.8.1.tgz: package/modules/components/switch/Switch.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Switch from './Switch';


const TestSwitch = Switch({
    block: purebem.of('test-switch'),
    displayName: 'TestSwitch',
});

test('should be checked when clicked and is unchecked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).toHaveBeenCalledWith(true);
});

test('should be unchecked when clicked and is checked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).toHaveBeenCalledWith(false);
});

test('should remain unchecked when disabled and clicked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).not.toHaveBeenCalled();
});

test('should remain checked when disabled and clicked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('click');

    expect(onChange).not.toHaveBeenCalled();
});

test('should be checked when using space and is unchecked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).toHaveBeenCalledWith(true);
});

test('should be unchecked when using space and is checked', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).toHaveBeenCalledWith(false);
});

test('should remain unchecked when disabled and using space', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ false } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).not.toHaveBeenCalled();
});

test('should remain checked when disabled and using space', () => {
    const onChange = jest.fn();
    const component = mount(
        <TestSwitch
            disabled={ true }
            onChange={ onChange }
            value={ true } />
    );

    component.find('TestSwitchLever').simulate('keydown', { which: 32 });

    expect(onChange).not.toHaveBeenCalled();
});
